summaryrefslogtreecommitdiffstats
path: root/src/server/PortImpl.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/server/PortImpl.hpp')
-rw-r--r--src/server/PortImpl.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/server/PortImpl.hpp b/src/server/PortImpl.hpp
index ccefa0f1..f084a6e5 100644
--- a/src/server/PortImpl.hpp
+++ b/src/server/PortImpl.hpp
@@ -211,8 +211,8 @@ public:
virtual SampleCount next_value_offset(SampleCount offset,
SampleCount end) const;
- /** Update value buffer to be current as of `offset`. */
- virtual void update_values(SampleCount offset) = 0;
+ /** Update value buffer for `voice` to be current as of `offset`. */
+ virtual void update_values(SampleCount offset, uint32_t voice) = 0;
void force_monitor_update() { _force_monitor_update = true; }